<div align="right">
  <a href='https://foramgeochem.readthedocs.io/en/latest/'>
    <img src='https://readthedocs.org/projects/foramgeochem/badge/?version=latest' alt='Documentation Status' height=18 />
  </a>
</div>

# ForamGeochem
Tools for working with foraminifera geochemistry and derived palaeoproxies
